proc UniformErr {} {
    set err [new ErrorModel/CL]
    $err unit packet
    return $err
}

Mac/802_11 set Arf_ 0
Node/MobileNode set error_ .00
Node/MobileNode set switch_time_ .001

#power and noise values taken from "Efficient Geographic Routing in Multihop Wireless Networks", S. Lee, B. Bhatacharjee, S. Banerjee
Phy/WirelessPhy set ambient_noise_ .0000000000012
Phy/WirelessPhy set Pt_ 0.020
Phy/WirelessPhy set CSThresh_ 10

# 24 bytes sent at 1Mbps
Mac/802_11 set PreambleLength_ 144

#clear_rt_on_switch indicates if the routing tables should be cleared when an interface changes channels. 1 = clear routing tables, 0 = leave routing tables
Node/MobileNode set clear_rt_on_switch_         1;



set val(chan)           Channel/WirelessChannel    ;# Channel Type
set val(prop)           Propagation/TwoRayGround   ;# radio-propagation model
set val(netif)          Phy/WirelessPhy            ;# network interface type
set val(mac)            Mac/802_11                 ;# MAC type
set val(ifq)            Queue/DropTail/PriQueue    ;# interface queue type
set val(ll)             LL                         ;# link layer type
set val(ant)            Antenna/OmniAntenna        ;# antenna model
set val(ifqlen)         50                         ;# max packet in ifq
set val(nn)             6                          ;# number of mobilenodes
set val(rp)             AODV                ;# routing protocol
set val(x)		800
set val(y)		1000
set val(length)         800                  ;#length of simulation


# Initialize Global Variables
set ns_		[new Simulator]
set tracefd     [open ./example2.tr w]
#$ns_ use-newtrace
$ns_ trace-all $tracefd


# set up topography object
set topo       [new Topography]

$topo load_flatgrid $val(x) $val(y)

# Create God
create-god [expr $val(nn)]

#=====================================	
#must set ErrorModel/CL to get gray model
set inerrProc_ "UniformErr"
set outerrProc_ ""
set FECProc_ ""
set propInstance_ [new $val(prop)]
set port [Node set rtagent_port_]


# configure node, please note the change below.
$ns_ node-config -adhocRouting $val(rp) \
		-llType $val(ll) \
		-macType $val(mac) \
		-ifqType $val(ifq) \
		-ifqLen $val(ifqlen) \
		-antType $val(ant) \
		-propType $val(prop) \
		-phyType $val(netif) \
		-channelType $val(chan) \
		-topoInstance $topo \
		-agentTrace ON \
		-routerTrace OFF \
		-macTrace OFF \
		-movementTrace OFF \
                -IncomingErrProc UniformErr


for {set i 0} {$i < $val(nn) } {incr i} {
    # create the node
    set node_($i) [$ns_ node]  
    #random-motion 0
    $node_($i) enable-arf
}

# Place nodes
$node_(0) set X_ 50.0
$node_(0) set Y_ 100.0
$node_(0) set Z_ .9

$node_(1) set X_ 50.0
$node_(1) set Y_ 100.0
$node_(1) set Z_ .9

$node_(2) set X_ 50.0
$node_(2) set Y_ 100.0
$node_(2) set Z_ .9

$node_(3) set X_ 50.0
$node_(3) set Y_ 180.0
$node_(3) set Z_ .9

$node_(4) set X_ 50.0
$node_(4) set Y_ 180.0
$node_(4) set Z_ .9

$node_(5) set X_ 50.0
$node_(5) set Y_ 180.0
$node_(5) set Z_ .9

# Create transmissions
set tcp1 [new Agent/TCP]
set sink1 [new Agent/TCPSink]
$node_(3) attach $tcp1 30
$node_(0) attach $sink1 30
$ns_ connect $tcp1 $sink1
set ftp1 [new Application/FTP]
$ftp1 attach-agent $tcp1
# Create transmissions
set tcp2 [new Agent/TCP]
set sink2 [new Agent/TCPSink]
$node_(4) attach $tcp2 31
$node_(1) attach $sink2 31
$ns_ connect $tcp2 $sink2
set ftp2 [new Application/FTP]
$ftp2 attach-agent $tcp2
# Create transmissions
set tcp3 [new Agent/TCP]
set sink3 [new Agent/TCPSink]
$node_(5) attach $tcp3 32
$node_(2) attach $sink3 32
$ns_ connect $tcp3 $sink3
set ftp3 [new Application/FTP]
$ftp3 attach-agent $tcp3

$ns_ at 70.2 "puts \"Demonstrate fading. Node0 and Node3 on channel 1\""
$ns_ at 70.2 "puts \"All node pairs are 80m appart\""
$ns_ at 70.0 "$node_(0) switch-channel 1"
$ns_ at 70.0 "$node_(3) switch-channel 1"
$ns_ at 70.1 "$ftp1 produce 1000"
$ns_ at 75.0 "puts \"Node3 data rate: \[$node_(3) dump-arf-rate\]\\n\""

#$ns_ at 75.0 "$ftp1 stop"
#$ns_ at 75.0 "$ftp2 stop"

$ns_ at 100 "puts \"Node1 on channel 1 and Node4 on channel 3\""
$ns_ at 100.0 "$node_(1) switch-channel 1"
$ns_ at 100.0 "$node_(4) switch-channel 3"
$ns_ at 100.1 "$ftp2 produce 1000"
$ns_ at 112.0 "puts \"Node4 data rate: \[$node_(4) dump-arf-rate\]\\n\""
$ns_ at 103.0 "$ftp1 stop"
$ns_ at 103.0 "$ftp2 stop"


$ns_ at 150 "puts \"Node2 on channel 1 and Node5 on channel 5\""
$ns_ at 150.0 "$node_(2) switch-channel 1"
$ns_ at 150.0 "$node_(5) switch-channel 5"
$ns_ at 150.1 "$ftp3 produce 1000"
$ns_ at 162.0 "puts \"Node5 data rate: \[$node_(5) dump-arf-rate\]\\n\""
$ns_ at 153.0 "$ftp1 stop"
$ns_ at 153.0 "$ftp2 stop"


$ns_ at $val(length) "stop"
$ns_ at [expr {$val(length) +.0001}] "puts \"NS EXITING...\" ; $ns_ halt"

proc stop {} {
    global ns_ tracefd
    $ns_ flush-trace
    close $tracefd
}

puts "Starting Simulation..."
$ns_ run
